@@ -1,17 +1,15 @@
+GtkWidget* create_hotlist_popup();
+
 void add_to_hotlist(char* nick);
 void remove_from_hotlist(char* nick);
 void cmd_hotlist_ack(char* data);
 void cmd_user_sign_on(char *data);
 void cmd_user_sign_off(char *data);
 
-file_t* file_create_from_browse_response(char* data);
-
-void cmd_browse_response(char* data);
-void file_insert_hotlist(file_t *file);
-void cmd_browse_end(char* nick);
-
 void cmd_hotlist_error(char* data);
 
-GtkCTreeNode* is_user_in_hotlist(char* user);
-void hotlist_search(char* expression);
+int is_user_in_hotlist(char* user);
+void hotlist_search(search_pattern_t* search);
+void hotlist_update_user();
 void hotlist_update_stats();
+void hotlist_remove_user_files(user_t* userinfo);
